@@ -3,16 +3,20 @@
 
 #include <QObject>
 #include <QMutex>
+#include <QTimer>
 #include <memory>
 
 class KEY6;
+class JOY6;
 
 //キーボードの状態を監視し、仮想キーボードに通知する
 class KeyStateWatcher : public QObject
 {
 	Q_OBJECT
 public:
-	explicit KeyStateWatcher(std::shared_ptr<KEY6> key, QObject *parent = nullptr);
+	explicit KeyStateWatcher(KEY6* key, JOY6* joy, QObject *parent = nullptr);
+	void start();
+	void stop();
 
 signals:
 	void stateChanged(
@@ -27,13 +31,13 @@ signals:
 
 public:
 	enum Modifiers {
-		SHIFT	= 0x01,
-		CTRL	= 0x02,
-		GRAPH	= 0x04,
-		KANA	= 0x08,
-		KKANA	= 0x16,
-		CAPS	= 0x32,
-		ROMAJI	= 0x64,
+		SHIFT	= 0b00000001,
+		CTRL	= 0b00000010,
+		GRAPH	= 0b00000100,
+		KANA	= 0b00001000,
+		KKANA	= 0b00010000,
+		CAPS	= 0b00100000,
+		ROMAJI	= 0b01000000,
 	};
 	int GetModifierStatus();
 
@@ -43,7 +47,8 @@ protected slots:
 	void poll();
 
 protected:
-	std::shared_ptr<KEY6> Key;	// 監視対象のキーボード
+	KEY6* Key;	// 監視対象のキーボード
+	JOY6* Joy;	// 監視対象のジョイスティック
 
 	bool ON_SHIFT;	// SHIFT
 	bool ON_CTRL;	// CTRL
@@ -54,6 +59,7 @@ protected:
 	bool ON_ROMAJI;	// ローマ字入力
 
 	QMutex mutex;
+	QTimer* Timer;
 };
 
 #endif // KEYSTATEWATCHER_H
