@@ -203,7 +203,7 @@ void P6VXApp::startup()
 	}
 
 	// P6VXデフォルト設定
-#ifndef NOOPENGL
+#ifndef NO_HWACCEL
 	setDefaultSetting(keyHwAccel, true);
 #endif
 	setDefaultSetting(keyFixMagnification, false);
@@ -470,7 +470,7 @@ void P6VXApp::clearLayout(HWINDOW Wh)
 	QGraphicsScene* scene = view->scene();
 	scene->clear();
 
-#ifndef NOOPENGL
+#ifndef NO_HWACCEL
 	// ステータスバー非表示またはフルスクリーン、かつTILTモードが有効になっている場合、背景を描く
 	if( (!Cfg->GetValue(CB_DispStatus)|| Cfg->GetValue(CB_FullScreen)) &&
 		#ifndef NOMONITOR
@@ -795,6 +795,22 @@ void P6VXApp::executeEmulation()
 		}
 	}
 
+	// スタートアップ時にどこでもSAVEファイルから復元するオプション
+	auto loadState = property("loadstate");
+	if (loadState.isValid()){
+		auto loadStatePath = QSTR2P6VPATH(loadState.toString());
+		if (!OSD_FileExist(loadStatePath)){
+			Error::SetError(Error::DokoReadFailed);
+			OSD_Message( P6CoreObj ? P6CoreObj->GetWindowHandle() : nullptr,
+						Error::GetErrorText(), GetText( TERR_ERROR ), OSDR_OK | OSDM_ICONERROR );
+			Error::Clear();
+		}
+		Cfg->SetDokoFile(loadStatePath);
+		Restart = EL6::Dokoload;
+		// スタートアップファイル名をリセット
+		setProperty("loadstate", QVariant());
+	}
+
 	switch( Restart ){
 	case EL6::Quit:	// 通常起動
 #ifdef AUTOSUSPEND
@@ -840,7 +856,13 @@ void P6VXApp::executeEmulation()
 		break;
 	}
 
+	// 前回実行時のエミュレーションコアオブジェクトを破棄、入れ替え
+	if (!KeyWatcher.isNull()){
+		KeyWatcher->stop();
+		KeyWatcher->deleteLater();
+	}
 	if (!P6Core.isNull()){
+		P6Core->Stop();
 		P6Core->deleteLater();
 	}
 	P6Core = P6CoreObj.release();
@@ -849,10 +871,7 @@ void P6VXApp::executeEmulation()
 	P6Core->SetPaletteTable(PaletteTable, Cfg->GetValue( CV_ScanLineBr ));
 
 	// キーボード状態監視
-	if (!KeyWatcher.isNull()){
-		KeyWatcher->deleteLater();
-	}
-	KeyWatcher = new KeyStateWatcher(P6Core->GetKeyboard(), this);
+	KeyWatcher = new KeyStateWatcher(P6Core->GetKeyboard(), P6Core->GetJoystick(), this);
 	MWidget->setKeyStateWatcher(KeyWatcher);
 
 	// 以降、ウィンドウが閉じたらアプリを終了する
@@ -870,9 +889,13 @@ void P6VXApp::postExecuteEmulation()
 	Restart = Adaptor->getReturnCode();
 	Adaptor->setEmulationObj(nullptr);
 
+	// エミュレーションコアオブジェクトを破棄
+	if (!KeyWatcher.isNull()){
+		KeyWatcher->stop();
+		KeyWatcher->deleteLater();
+	}
 	if(!P6Core.isNull()){
 		P6Core->Stop();
-
 #ifdef AUTOSUSPEND
 		// 自動サスペンド有効時はここでSAVE
 		if( Restart == EL6::Quit ){
@@ -915,7 +938,7 @@ void P6VXApp::terminateEmulation()
 
 
 
-void P6VXApp::handleSpecialKeys(QKeyEvent* ke, int& keyCode)
+void P6VXApp::handleSpecialKeys(QKeyEvent* ke, int& keyCode, Qt::KeyboardModifiers &modifiers)
 {
 	quint32 nativeKey = ke->nativeScanCode();
 #if 0
@@ -959,23 +982,73 @@ void P6VXApp::handleSpecialKeys(QKeyEvent* ke, int& keyCode)
 
 void P6VXApp::finishKeyEvent(Event &ev)
 {
-	// qDebug() << ev.key.sym << QChar(ev.key.unicode);
+#if 0
+	qDebug() << ev.key.mod
+			 << ev.key.sym
+			 << ev.key.type
+			 << QChar(ev.key.unicode);
+#endif
 
-	// かな、グラフィックキー有効時はキーイベントをそのまま送信
-	auto mod = KeyWatcher->GetModifierStatus();
-	if ( mod & KeyStateWatcher::KANA ||
-		 mod & KeyStateWatcher::KKANA ||
-		 mod & KeyStateWatcher::GRAPH ||
-		 mod & KeyStateWatcher::CAPS ||
-		 mod & KeyStateWatcher::KANA ||
-		 mod & KeyStateWatcher::ROMAJI) {
-		OSD_PushEvent(ev);
-		return;
+	// イベント時点でのモディファイヤキー状態
+	bool shiftStatus = (ev.key.mod & KVM_SHIFT) ? true : false;
+	bool ctrlStatus = (ev.key.mod & KVM_CTRL) ? true : false;
+
+	static const Event shiftDownEvent =
+		{
+			.key = { EV_KEYDOWN, true, KVC_LSHIFT, KVM_LSHIFT, 0 }
+		};
+	static const Event shiftUpEvent =
+		{
+			.key = { EV_KEYUP, false, KVC_LSHIFT, KVM_LSHIFT, 0 }
+		};
+	static const Event ctrlDownEvent =
+		{
+			.key = { EV_KEYDOWN, true, KVC_LCTRL, KVM_LCTRL, 0 }
+		};
+	static const Event ctrlUpEvent =
+		{
+			.key = { EV_KEYUP, false, KVC_LCTRL, KVM_LCTRL, 0 }
+		};
+
+	// 特殊ファンクションキー(P6VX独自アサイン)
+	// 英語キーボード、省スペースキーボード向けに
+	// ctrl+ファンクションキーで特殊キー入力をサポート
+	if (ctrlStatus){
+		bool specialFuncKey = true;
+		switch (ev.key.sym) {
+		// PAGEキー(Ctrl+F8)
+		case KVC_F8:
+			ev.key.sym = KVC_PAGEUP;		break;
+		// STOPキー(Ctrl+F9)
+		case KVC_F9:
+			ev.key.sym = KVC_END;			break;
+		// MODEキー(Ctrl+F10)
+		case KVC_F10:
+			ev.key.sym = KVC_PAGEDOWN;		break;
+		// CAPSキー(Ctrl+F11)
+		case KVC_F11:
+			ev.key.sym = KVC_SCROLLLOCK;	break;
+		// かなキー(Ctrl+F12)
+		case KVC_F12:
+			ev.key.sym = KVC_PAUSE;			break;
+		default:
+			specialFuncKey = false;
+		}
+		if (specialFuncKey) {
+			// 特殊ファンクションキーに該当した場合は
+			// 一旦ctrlキーを離すイベントを送る
+			OSD_PushEvent(ctrlUpEvent);
+			// 変換後のキーはctrl無しとして送る
+			ev.key.mod = (PCKEYmod)(ev.key.mod & ~KVM_CTRL);
+			OSD_PushEvent(ev);
+			return;
+		}
 	}
 
-	// イベント時点でのシフトキー状態
-	bool shiftStatus = ev.key.mod & KVM_SHIFT;
-
+	// 英語キーボードの場合、@の入力にSHIFTキーが必要なため、
+	// この場合P6エミュ側にSHIFT+@のキーコードを送っても何も入力されない。
+	// 本来意図した文字が入力されるよう、
+	// キーシンボルとモディファイヤキーを修正する。
 	struct FixInfo
 	{
 		PCKEYsym sym;
@@ -1011,19 +1084,17 @@ void P6VXApp::finishKeyEvent(Event &ev)
 		{	QUNI('?'),	{ KVC_SLASH,		true}	},
 	};
 #undef QUNI
-	static const Event shiftDownEvent =
-	{
-		.key = { EV_KEYDOWN, true, KVC_LSHIFT, KVM_LSHIFT, 0 }
-	};
-	static const Event shiftUpEvent =
-	{
-		.key = { EV_KEYUP, false, KVC_LSHIFT, KVM_LSHIFT, 0 }
-	};
 
-	// 英語キーボードの場合、@の入力にSHIFTキーが必要なため、
-	// この場合P6エミュ側にSHIFT+@のキーコードを送っても何も入力されない。
-	// 本来意図した文字が入力されるよう、
-	// キーシンボルとモディファイヤキーを修正する。
+	// かな、グラフィックキー有効時はキーイベントをそのまま送信
+	auto mod = KeyWatcher->GetModifierStatus();
+	if ( mod & KeyStateWatcher::KANA ||
+		mod & KeyStateWatcher::KKANA ||
+		mod & KeyStateWatcher::GRAPH ||
+		mod & KeyStateWatcher::KANA ) {
+		OSD_PushEvent(ev);
+		return;
+	}
+
 	if (fixMap.count(ev.key.unicode)){
 		auto i = fixMap.at(ev.key.unicode);
 		ev.key.sym = i.sym;
@@ -1124,6 +1195,7 @@ bool P6VXApp::notify ( QObject * receiver, QEvent * event )
 
 		// キーコードを特定
 		int keyCode = Qt::Key_unknown;
+		Qt::KeyboardModifiers modifiers = ke->modifiers();
 #ifdef IRREGULAR_KEYBOARD
 		// UMPC内蔵小型キーボードなど、特殊なキーボードの場合
 		// 一般的なキーボードとコードのアンマッチがあるので
@@ -1137,7 +1209,7 @@ bool P6VXApp::notify ( QObject * receiver, QEvent * event )
 		keyCode = ke->key();
 #endif
 		// 特殊キー対策
-		handleSpecialKeys(ke, keyCode);
+		handleSpecialKeys(ke, keyCode, modifiers);
 
 		// 以下の場合は入力イベントをエミュレータ側に渡さず、Qtに渡す
 		// (メニューやダイアログでキーボードを使えるようにするため)
@@ -1171,13 +1243,13 @@ bool P6VXApp::notify ( QObject * receiver, QEvent * event )
 		ev.key.state   = event->type() == QEvent::KeyPress ? true : false;
 		ev.key.sym     = OSD_ConvertKeyCode( keyCode );
 		ev.key.mod	   = (PCKEYmod)(
-					( ke->modifiers() & Qt::ShiftModifier ? KVM_SHIFT : KVM_NONE )
-					| ( ke->modifiers() & Qt::ControlModifier ? KVM_CTRL : KVM_NONE )
-					| ( ke->modifiers() & Qt::AltModifier ? KVM_ALT : KVM_NONE )
-					| ( ke->modifiers() & Qt::MetaModifier ? KVM_CTRL : KVM_NONE )
-					| ( ke->modifiers() & Qt::KeypadModifier ? KVM_NUM : KVM_NONE )
+					( modifiers & Qt::ShiftModifier ? KVM_SHIFT : KVM_NONE )
+					| ( modifiers & Qt::ControlModifier ? KVM_CTRL : KVM_NONE )
+					| ( modifiers & Qt::AltModifier ? KVM_ALT : KVM_NONE )
+					| ( modifiers & Qt::MetaModifier ? KVM_CTRL : KVM_NONE )
+					| ( modifiers & Qt::KeypadModifier ? KVM_NUM : KVM_NONE )
 					// CAPSLOCKは検出できない？
-					// | ( ke->modifiers() & Qt::caps ? KVM_NUM : KVM_NONE )
+					// | ( modifiers & Qt::caps ? KVM_NUM : KVM_NONE )
 					);
 		ev.key.unicode = ke->text().utf16()[0];
 		finishKeyEvent(ev);
@@ -1189,13 +1261,17 @@ bool P6VXApp::notify ( QObject * receiver, QEvent * event )
 		OSD_PushEvent(EV_JOYAXISMOTION);
 		break;
 	}
-#ifdef ALWAYSFULLSCREEN
 	case QEvent::ApplicationStateChange:
 		if(P6Core){
-			if(reinterpret_cast<QApplicationStateChangeEvent*>(event)->applicationState()){
+			auto state = reinterpret_cast<QApplicationStateChangeEvent*>(event)->applicationState();
+			switch (state){
+			case Qt::ApplicationActive:
 				P6Core->Start();
-			}else{
+				break;
+			default:;
+#ifdef ALWAYSFULLSCREEN
 				P6Core->Stop();
+#endif
 #ifdef AUTOSUSPEND
 				// 自動サスペンド有効時はここでSAVE
 				P6Core->UI_DokoSave(0);
@@ -1203,7 +1279,6 @@ bool P6VXApp::notify ( QObject * receiver, QEvent * event )
 			}
 		}
 		break;
-#endif
 	default:;
 	}
 
