@@ -475,7 +475,7 @@ void QtEL6::ShowPopupImpl(int x, int y)
 	if (cfg->GetValue(CB_DispNTSC)) disp43->setChecked(true);
 	QAction* scanLine = addCommand(settingsMenu, tr("スキャンライン"), ID_SCANLINE, true);
 	if (cfg->GetValue(CB_ScanLine)) scanLine->setChecked(true);
-#ifndef NOOPENGL
+#ifndef NO_HWACCEL
 	QAction* hwAccel = addCommand(settingsMenu, tr("ハードウェアアクセラレーション"), ID_HWACCEL, true);
 	if (app->getSetting(P6VXApp::keyHwAccel).toBool()) hwAccel->setChecked(true);
 #endif
@@ -578,9 +578,14 @@ int QtEL6::GetSpeedRatio()
 	return this->sche->GetSpeedRatio();
 }
 
-std::shared_ptr<KEY6> QtEL6::GetKeyboard()
+KEY6* QtEL6::GetKeyboard()
 {
-	return vm->key;
+	return vm->key.get();
+}
+
+JOY6* QtEL6::GetJoystick()
+{
+	return this->joy.get();
 }
 
 bool QtEL6::IsMonitor()
@@ -629,3 +634,8 @@ void QtEL6::UI_DokoLoad(int slot, bool ask)
 	EL6::UI_DokoLoad(slot, ask);
 }
 
+void QtEL6::UI_DokoLoad(const P6VPATH& path)
+{
+	EL6::UI_DokoLoad(path);
+}
+
