@@ -17,13 +17,15 @@ public:
 	void SetPauseEnable(bool en);
 	int GetSoundReadySize();
 	int GetSpeedRatio();
-	std::shared_ptr<KEY6> GetKeyboard();
+	KEY6 *GetKeyboard();
+	JOY6 *GetJoystick();
 	bool IsMonitor();
 	void SetPaletteTable(QVector<QRgb>& palette, int scanbr);
 
 	// 親クラスのメソッドをpublicでオーバーライド
 	void UI_DokoSave( int slot );
 	void UI_DokoLoad( int slot, bool ask = false );
+	void UI_DokoLoad( const P6VPATH& path = "" );
 public slots:
 	void UpdateFPS();
 };
