@@ -5,8 +5,8 @@ function prerequisite(){
 if [ $((NO_DEPENDENCY)) == 0 ]; then
 $SCRIPT_DIR/../qtspell/qtspell.sh
 exitOnError
-$SCRIPT_DIR/../twaindsm/twaindsm.sh
-exitOnError
+# $SCRIPT_DIR/../twaindsm/twaindsm.sh
+# exitOnError
 fi
 
 #必要ライブラリ
@@ -33,7 +33,7 @@ echo "gImageReader is already installed."
 exit 0
 fi
 
-    GIMAGEREADER_VERSION=3.4.2
+    GIMAGEREADER_VERSION=3.4.3
 if [ "$GIMAGEREADER_GIT" != "" ]; then
     GIMAGEREADER_SRC_DIR=gImageReader-git
     git clone https://github.com/manisandro/gImageReader.git $GIMAGEREADER_SRC_DIR 2> /dev/null
