@@ -14,6 +14,7 @@ ${MINGW_PACKAGE_PREFIX}-clang-tools-extra \
 ${MINGW_PACKAGE_PREFIX}-llvm \
 ${MINGW_PACKAGE_PREFIX}-pkgconf \
 ${MINGW_PACKAGE_PREFIX}-python \
+${MINGW_PACKAGE_PREFIX}-protobuf \
 ${MINGW_PACKAGE_PREFIX}-xmlstarlet \
 ${MINGW_PACKAGE_PREFIX}-vulkan-headers \
 ${MINGW_PACKAGE_PREFIX}-dbus \
@@ -57,8 +58,8 @@ apply_patch_with_msg() {
   done
 }
 
-QT_MAJOR_VERSION=6.8
-QT_MINOR_VERSION=.3
+QT_MAJOR_VERSION=6.9
+QT_MINOR_VERSION=.2
 QT_VERSION=$QT_MAJOR_VERSION$QT_MINOR_VERSION
 
 function makeQtSourceTree(){
@@ -100,10 +101,10 @@ else
     014-imageformats-transitive-dependencies.patch \
     015-qt6-windeployqt-fixes.patch
 
-  cd qtquick3d/src/3rdparty/assimp/src
-  apply_patch_with_msg \
-    016-fix-build-on-mingw64.patch
-  cd -
+  # cd qtquick3d/src/3rdparty/assimp/src
+  # apply_patch_with_msg \
+  #   016-fix-build-on-mingw64.patch
+  # cd -
 
   local _ARCH_TUNE
   if [[ ${CARCH} == x86_64 ]]; then
@@ -133,7 +134,7 @@ makeQtSourceTree static
 exitOnError
 
 #static版
-QT6_STATIC_BUILD=qt6-static-$MSYSTEM
+QT6_STATIC_BUILD=/c/qt6-static-$MSYSTEM
 rm -rf $QT6_STATIC_BUILD
 mkdir $QT6_STATIC_BUILD
 pushd $QT6_STATIC_BUILD
@@ -211,36 +212,36 @@ pushd $QT6_STATIC_BUILD
     -DOPENSSL_USE_STATIC_LIBS=ON \
     -DZLIB_USE_STATIC_LIBS=ON \
     -DBUILD_qtwebengine=OFF \
-    $(cygpath -am ../$QT_SOURCE_DIR) 
+    $(cygpath -am $EXTLIB/$QT_SOURCE_DIR) 
 
     #カスタマイズポイント
     # -DCMAKE_INSTALL_PREFIX=$(cygpath -am $QT6_STATIC_PREFIX) \
-    # -DCMAKE_BUILD_TYPE=MinSizeRel \
-    # -DFEATURE_optimize_size=ON \
     # -DBUILD_WITH_PCH=OFF \
     # -DINPUT_jasper=no \
     # -DFEATURE_SYSTEM_*=OFF
     # -DFEATURE_opengl_desktop=OFF \
     # -DFEATURE_ffmpeg=OFF \
     # 最後のソースパス↓
-    # $(cygpath -am ../$QT_SOURCE_DIR) 
+    # $(cygpath -am $EXTLIB/$QT_SOURCE_DIR) 
 
 #---------------------------------------------------
 
   export PATH=$PWD/bin:$PATH
 
-cp config.summary ../qt6_config_summary_$MSYSTEM.txt
+cp config.summary $EXTLIB/qt6_config_summary_$MSYSTEM.txt
 
 nice -n19 cmake --build .
 exitOnError
+nice -n19 cmake --build . --target docs
+exitOnError
 
 cmake --install .
 exitOnError
-
+nice -n19 cmake --build . --target install_docs
+exitOnError
 
 popd
-
-# rm -rf $QT6_STATIC_BUILD
+rm -rf $QT6_STATIC_BUILD
 }
 
 
